#GIT_CMT=ef606a27deb6a275c7fe632a5afa0a0c8ca43365
# Copyright(c) 2015,2016 Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# Python major version.
%{expand: %%define pyver %(python -c 'import sys;print(sys.version[0:3])')}

# Package version
%global package_version 4.0.1
%global container_tag 4.0

# Kolla user name and group name (DO NOT CHANGE THESE!)
%global kolla_user      kolla
%global kolla_group     %{kolla_user}

# Docker group name
%global docker_group    docker


Summary:        OpenStack Kolla Deployment
Name:           openstack-kolla
Version:        %{package_version}
Release:    2.el6
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla
Source0: openstack-kolla-4.0.1.tar.bz2
BuildArch:      noarch

BuildRequires:  python                      >= 2.6
BuildRequires:  python-setuptools           >= 0.9.8
BuildRequires:  python-pbr                  >= 1.3.0
BuildRequires:  git                         >= 1.7.1


%description
OpenStack Kolla meta package


%prep
%setup -q -n %{name}-%{version}


%build
#Replace the openstack_release here inorder to name  '.egg-info' file with version
sed -i -e 's@^openstack_release:.*@openstack_release: "%{package_version}"@' ansible/group_vars/all.yml

# Generate a temporary pkg-info file to make pbr happy
git init .
PKGINFO_NAME=$(sed -n -e '/^name/ s/name\s=\s//p' setup.cfg)
PKGINFO_VERSION=$(sed -n -e '/^version/ s/version\s=\s//p' setup.cfg)
if [[ -z "${PKGINFO_VERSION}" ]]
then
    _v=$(sed \
          -n \
          -e '/^openstack_release/ s/openstack_release:.*"\(.*\)"/\1/p' \
          ansible/group_vars/all.yml)
     [[ ! -z "${_v}" ]] \
        && PKGINFO_VERSION="${_v}" \
        || PKGINFO_VERSION="%{package_version}"
fi
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: ${PKGINFO_NAME}
Version: ${PKGINFO_VERSION}
__EOF__

#Patches required to retain the /usr/share/kolla dir structure
mv kolla_ansible kolla
sed -i -e 's@kolla_ansible@kolla@' setup.cfg
sed -i -e 's@share/kolla-ansible@share/kolla@' setup.cfg
sed -i -e 's@share/kolla-ansible@share/kolla@' tools/kolla-ansible
sed -i -e 's@from[ ]*kolla_ansible@from kolla@' doc/conf.py
sed -i -e 's@from[ ]*kolla_ansible@from kolla@' releasenotes/source/conf.py

# Build the package
%{__python} setup.py build


%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Create the required directory structures
mkdir -m 0750 -p %{buildroot}%{_datadir}/kolla
cat >%{buildroot}%{_datadir}/kolla/LICENSE.TXT <<EOF
Oracle OpenStack for Oracle Linux is a management software package
comprised of various OpenStack components combined with independent software
programs that operate as OpenStack services. These independent programs
include parts of MySQL Community Edition, Oracle Linux and MySQL Cluster
Community Edition. The license for each OpenStack component, as well as the
licenses for each independent program, can be found in the root folder for
each component and/or program or in the specific Docker Container or RPM
package.
EOF

mkdir -m 0750 -p %{buildroot}%{_sysconfdir}/kolla
cp -r etc/kolla/* %{buildroot}%{_sysconfdir}/kolla/


chmod 0600 %{buildroot}%{_sysconfdir}/kolla/passwords.yml
mv %{buildroot}%{_sysconfdir}/kolla/globals.yml \
   %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
chmod 0660 %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__

# Create the Kolla sudo file
mkdir -p %{buildroot}%{_sysconfdir}/sudoers.d
_group=%{kolla_group}
cat >%{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user} <<__EOF__
Defaults: %{kolla_user} env_keep += "OS_AUTH_URL OS_TENANT_ID OS_TENANT_NAME OS_PROJECT_NAME"
Defaults: %{kolla_user} env_keep += "OS_USERNAME OS_PASSWORD  OS_REGION_NAME REGISTRY"
Defaults: %{kolla_user} env_keep += "OS_PROJECT_DOMAIN_ID     OS_USER_DOMAIN_ID"
Defaults: %{kolla_user} env_keep += "OS_VOLUME_API_VERSION    OS_IDENTITY_API_VERSION"

Defaults: %{kolla_user} !requiretty
Cmnd_Alias KOLLA_ADMIN_CMDS = ALL
%{kolla_user} ALL = (root) NOPASSWD: KOLLA_ADMIN_CMDS

Defaults: %${_group} !requiretty
Cmnd_Alias KOLLA_CMDS = /usr/bin/ansible, /usr/bin/ansible-playbook, /bin/ls, /bin/id
%${_group} ALL = (%{kolla_user}) NOPASSWD: KOLLA_CMDS
__EOF__
chmod 0600 %{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user}

mv -f %{buildroot}%{_datadir}/kolla/ansible/inventory \
      %{buildroot}%{_datadir}/kolla/ansible/inventory_samples

%clean
rm -rf %{buildroot}


%files
%defattr(-, root, root)
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst
%attr(0444, root, root) %{_datadir}/kolla/LICENSE.TXT
%{python_sitelib}/kolla*.egg-info


%package -n     openstack-kolla-devel
Summary:        OpenStack Kolla development files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       GitPython                   >= 1.0.1
Requires:       python-gitdb                >= 0.6.4
Requires:       python-pbr                  >= 1.3.0
Requires:       python-jinja2               >= 2.8
Requires:       openstack-kolla-ansible     = %{package_version}-%{release}


%description -n openstack-kolla-devel
Files used to develop Kolla OpenStack Docker images.


%files -n       openstack-kolla-devel
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst
%{_datadir}/kolla
%{python_sitelib}/*
%exclude %{_datadir}/kolla/LICENSE.TXT
%exclude %{_datadir}/kolla/ansible
%exclude %{_datadir}/kolla/tools/cleanup-containers
%exclude %{_datadir}/kolla/tools/cleanup-host
%exclude %{_datadir}/kolla/tools/cleanup-images
%exclude %{_datadir}/kolla/tools/stop-containers
%exclude %{_datadir}/kolla/tools/validate-docker-execute.sh
%exclude %{python_sitelib}/kolla*.egg-info
%exclude %{python_sitelib}/kolla/__init__*
%exclude %{python_sitelib}/kolla/cmd/__init__*
%exclude %{python_sitelib}/kolla/cmd/genpwd*


%package -n     openstack-kolla-ansible
Summary:        OpenStack Kolla Ansible playbooks and supporting files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sed                         >= 4.2.1
Requires:       ansible                     >= 2.3.1
Requires:       ansible                     <  2.3.2
Requires:       python-jinja2               >= 2.8
Requires:       python-netaddr              >= 0.7.5
Requires:       python2-debtcollector       >= 1.11.0
Requires:       python2-rfc3986             >= 0.3.1
Requires:       python-wrapt                >= 1.10.10
Requires:       python-funcsigs             >= 1.0.2
Requires:       python-monotonic            >= 0.6
Requires:       python2-oslo-utils          >= 3.22.0
Requires:       python2-oslo-config         >= 3.22.0
Requires:       python2-cryptography        >= 1.6
Requires:       openstack-kolla-user        = %{package_version}-%{release}

%description -n openstack-kolla-ansible
Ansible playbooks and support files to deploy Kolla in Docker containers.


%files -n       openstack-kolla-ansible
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc LICENSE
%config(noreplace) %{_sysconfdir}/kolla
%config(noreplace) %{_sysconfdir}/kolla/passwords.yml
%config(noreplace) %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-ansible
%{_datadir}/kolla/ansible
%{_datadir}/kolla/tools/cleanup-containers
%{_datadir}/kolla/tools/cleanup-host
%{_datadir}/kolla/tools/cleanup-images
%{_datadir}/kolla/tools/stop-containers
%{_datadir}/kolla/tools/validate-docker-execute.sh
%{python_sitelib}/kolla/__init__*
%{python_sitelib}/kolla/cmd/__init__*
%{python_sitelib}/kolla/cmd/genpwd*
%{python_sitelib}/kolla/cmd/mergepwd*
%{_bindir}/kolla-genpwd
%{_bindir}/kolla-mergepwd


%pre -n         openstack-kolla-ansible
case "$*" in
    0)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    if  test -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    then
        mv %{_datadir}/kolla/ansible/group_vars/__GLOBAL__ \
           %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
        chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
        chmod 0660 %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
    fi
    if  test -f %{_datadir}/kolla/ansible/group_vars/all.yml
    then
        mv %{_datadir}/kolla/ansible/group_vars/all.yml \
           %{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
        chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
        chmod 0644 %{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
    fi
    if test -d %{_datadir}/kolla/ansible/host_vars
    then
        if `ls %{_datadir}/kolla/ansible/host_vars/* 1> /dev/null 2>&1`
        then
            for file in %{_datadir}/kolla/ansible/host_vars/*;do mv "$file" "${file%}.rpmsave";done
        fi
    fi
    if   test -f %{_sysconfdir}/kolla/passwords.yml
    then
        cp -f %{_sysconfdir}/kolla/passwords.yml \
              %{_sysconfdir}/kolla/passwords.yml.rpmsave
    fi
fi
exit 0


%post -n        openstack-kolla-ansible
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Operations to support group / host variables
#
if ! test -d %{_datadir}/kolla/ansible/host_vars
then
    mkdir -m 0770 -p %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
fi
chmod 0770 %{_datadir}/kolla/ansible/group_vars

if [[ "${inst_type}" == "update" ]]
then
    #
    # Use the default release tag if upgrading from 3.x
    # Though we shouldn't hit that since we don't support
    # 3.x upgrades.  This is more useful going forward to
    # guide 4.x to 5.x upgrade behavior for this value
    #
    globals_yml=%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    if grep -q '^openstack_release.*:.*"3\.[01]\.[01].*' ${globals_yml}
    then
        sed -i \
            -e 's/^openstack_release.*:/#openstack_release:/' \
            ${globals_yml}
    fi
    rm -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmnew

    if test -f %{_sysconfdir}/kolla/passwords.yml.rpmsave
    then
        if test -f %{_sysconfdir}/kolla/passwords.yml.rpmnew
        then
            mv %{_sysconfdir}/kolla/passwords.yml.rpmnew %{_sysconfdir}/kolla/passwords.yml
        fi
        kolla-genpwd
        kolla-mergepwd --old %{_sysconfdir}/kolla/passwords.yml.rpmsave \
                       --new %{_sysconfdir}/kolla/passwords.yml \
                       --final %{_sysconfdir}/kolla/passwords.yml
        rm -f %{_sysconfdir}/kolla/passwords.yml.rpmsave
    fi
fi

#
# This forces the Oracle default values without changing what the user
#      might have set on his own
#
sed -i \
    -e 's/^docker_namespace:.*/docker_namespace: "openstack"/' \
    -e 's/^kolla_base_distro:.*/kolla_base_distro: "ol"/' \
    -e 's/^kolla_install_type:.*/kolla_install_type: "openstack"/' \
    -e 's/^openstack_release:.*/openstack_release: "%{container_tag}"/' \
    -e 's/^keepalived_virtual_router_id:.*/virtual_router_id: "51"\
keepalived_virtual_router_id: "{{ virtual_router_id }}"/' \
    -e 's/^cinder_backend_ceph:.*/cinder_backend_ceph: "no"/' \
    -e 's/^enable_cinder:.*/enable_cinder: "yes"/' \
    -e 's/^enable_multipathd:.*/enable_multipathd: "yes"/' \
    -e 's/^enable_murano:.*/enable_murano: "yes"/' \
    -e 's/^enable_barbican:.*/enable_barbican: "yes"/' \
    -e 's/^enable_central_logging:.*/enable_central_logging: "yes"/' \
    -e 's/^enable_aodh:.*/enable_aodh: "{{ \x27yes\x27 if enable_ceilometer | bool else \x27no\x27 }}"/' \
    -e 's/^docker_registry:.*/docker_registry: "container-registry.oracle.com"/' \
    -e 's@^rabbitmq_version:.*@rabbitmq_version: "rabbitmq_server-3.5.7/plugins/rabbitmq_clusterer-3.5.x-189b3a81.ez/rabbitmq_clusterer-3.5.x-189b3a81/ebin"@' \
    -e 's@^glance_file_datadir_volume:.*@glance_file_datadir_volume: "/var/lib/glance"@' \
    %{_datadir}/kolla/ansible/group_vars/all.yml

echo 'nova_hw_disk_discard: ""' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'cinder_iscsi_helper: "lioadm"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo "mysqlcluster_api_first_node_address: \"{{ hostvars[groups['mysqlcluster-api'][0]]['ansible_' + hostvars[groups['mysqlcluster-api'][0]]['api_interface']]['ipv4']['address'] }}\"" >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'ceilometer_database_address: "{{ mysqlcluster_api_first_node_address }}"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
exit 0


%postun -n      openstack-kolla-ansible
case "$*" in
    0)
        #
        # Remove/Erase package
        #
        inst_type="remove"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

exit 0



%package -n     openstack-kolla-utils
Summary:        OpenStack Kolla utilities.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       openstack-kolla             = %{package_version}


%description -n openstack-kolla-utils
Utilities for use with Kolla containers.


%files -n       openstack-kolla-utils
%attr(-, root, root) %doc LICENSE
%attr(755, root, root) %{_bindir}/docker-ostk



%package -n     openstack-kolla-user
Summary:        OpenStack Kolla user configuration.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sudo                        >= 1.7
Requires:       openstack-kolla             = %{package_version}-%{release}
Requires:       shadow-utils                >= 4.1


%description -n openstack-kolla-user
Create kolla user for use by OpenStack Kolla deployments.


%files -n       openstack-kolla-user
%attr(-, root, root) %doc LICENSE
%attr(0600, root, root) %{_sysconfdir}/sudoers.d/%{kolla_user}
%attr(0750, %{kolla_user}, %{kolla_group}) %dir %{_datadir}/kolla


%pre -n         openstack-kolla-user
/usr/sbin/groupadd -f -r %{docker_group} >/dev/null 2>&1
/usr/sbin/groupadd -f -r %{kolla_group}  >/dev/null 2>&1
if ! id %{kolla_user} >/dev/null 2>&1
then
    /usr/sbin/useradd \
      -b %{_datadir} \
      -c 'Kolla User' \
      -g %{kolla_group} \
      -G %{docker_group} \
      -m \
      -k /no_skel_dir \
      -N \
      -r \
      %{kolla_user}
    [[ $? -ne 0 ]] && exit 1
    chown -f %{kolla_user}:%{kolla_group} ~%{kolla_user}
    chmod -f 0750 ~%{kolla_user}
fi
exit 0


%post -n        openstack-kolla-user
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Setup sudoers for the user
#
if ! grep -q '^#include.*%{_sysconfdir}/sudoers.d' %{_sysconfdir}/sudoers
then
    echo '' >&2
    echo 'WARNING: %{_sysconfdir}/sudoers is NOT including the %{_sysconfdir}/sudoers.d files!!' >&2
    echo '         Appending to %{_sysconfdir}/sudoers directly' >&2
    echo '' >&2
    if ! grep -q '^%{kolla_user}.*NOPASSWD' %{_sysconfdir}/sudoers
    then
        cat %{_sysconfdir}/sudoers.d/%{kolla_user} >>%{_sysconfdir}/sudoers
    fi
fi

#
# Prepare the user for SSH access
#
if ! test -d ~%{kolla_user}/.ssh
then
    mkdir -p -m 0700 ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
fi
if ! test -f ~%{kolla_user}/.ssh/authorized_keys
then
    touch ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chmod 0600 ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
fi
exit 0



%package -n     openstack-kolla-preinstall
Summary:        OpenStack Kolla pre-install configuration.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sudo                        >= 1.7
Requires:       docker-engine               = 1.12.6
Requires:       btrfs-progs                 >= 4.2.2

Requires:       python-docker-py            >= 1.8.1
Requires:       python-six                  >= 1.9.0
Requires:       openstack-kolla-user        = %{package_version}-%{release}


%description -n openstack-kolla-preinstall
Prepare a system for use by OpenStack Kolla deployments.


%files -n       openstack-kolla-preinstall
%attr(-, root, root) %doc LICENSE


%post -n        openstack-kolla-preinstall
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Prevent 'Error! pty.fork() failed: out of pty devices' errors by forcing ptmxmode=666
#
if grep -q '^devpts' %{_sysconfdir}/fstab
then
    sed \
     -i \
     -e '/^devpts/ s/\(.*\)\(ptmxmode=[0-9]*\)\(.*\)/\1ptmxmode=666\3/' \
     %{_sysconfdir}/fstab
else
    echo 'devpts                  /dev/pts                devpts  rw,nosuid,noexec,relatime,gid=5,mode=620,ptmxmode=666 0 0' >>%{_sysconfdir}/fstab
fi

#
# If this is an Oracle VM Server, prepare the server
#
if test -x %{_sbindir}/ovm2openstack
then
    if [[ ! -h /run ]]
    then
        [[ -d /run ]] && mv -f /run /run.rpmsave
        ln -s %{_var}/run /run
    fi

    [[ ! -d %{_sharedstatedir}/kolla%{_sharedstatedir}/nova ]] && \
        mkdir -p %{_sharedstatedir}/kolla%{_sharedstatedir}/nova

    [[ ! -e %{_sharedstatedir}/nova ]] && \
        ln -s %{_sharedstatedir}/kolla%{_sharedstatedir}/nova \
              %{_sharedstatedir}/nova

    [[ ! -d %{_sharedstatedir}/nova/instances ]] && \
        mkdir -p %{_sharedstatedir}/nova/instances

    #
    # Ideally this should get migrated into the ovm2openstack script
    #
    for svc in multipathd iscsi iscsid oswatcher ovm-consoled ovs-devmon
    do
        [[ ! -z "$(service ${svc} status 2>/dev/null|grep running)" ]] && \
            service ${svc} stop >/dev/null 2>&1
        [[ ! -z "$(chkconfig --list ${svc} 2>/dev/null|grep on)" ]] && \
            chkconfig ${svc} off >/dev/null 2>&1
        chkconfig --del ${svc} >/dev/null 2>&1
    done
    [[ -f /etc/multipath.conf ]] && [[ ! -f /etc/multipath.conf.ovm ]] && \
        mv -f /etc/multipath.conf /etc/multipath.conf.ovm

    restart_libvirtd=""
    if ! grep -q '^listen_addr.*127.0.0.1' \
                 %{_sysconfdir}/libvirt/libvirtd.conf >/dev/null 2>&1
    then
        cp -f -p %{_sysconfdir}/libvirt/libvirtd.conf \
                  %{_sysconfdir}/libvirt/libvirtd.conf.rpmsave
        sed \
         -i \
         -e '/#tcp_port/c\tcp_port = "16509"' \
         -e '/#listen_addr/c\listen_addr = "0.0.0.0"' \
         -e '/#unix_sock_ro_perm/c\unix_sock_ro_perms = "0777"' \
         -e '/#unix_sock_rw_perm/c\unix_sock_rw_perms = "0770"' \
         -e '/#unix_sock_dir/c\unix_sock_dir = "/var/run/libvirt"' \
         -e '/#log_level/c\log_level = 3' \
         -e '/#listen_tls/c\listen_tls = 0' \
         -e '/#listen_tcp/c\listen_tcp = 1' \
         -e '/#auth_tcp/c\auth_tcp = "none"' \
         %{_sysconfdir}/libvirt/libvirtd.conf
        sed \
         -i \
         -e '/#LIBVIRTD_ARGS/c\LIBVIRTD_ARGS="--listen"' \
         %{_sysconfdir}/sysconfig/libvirtd
         restart_libvirtd="restart"
    fi

    #
    # Only run the ovm2openstack if it has not been run before
    #
    if [[ ! -f %{_sysconfdir}/sysconfig/ovm2openstack ]]
    then
        %{_sbindir}/ovm2openstack >/dev/null 2>&1
    else
        #
        # ONLY restart libvirtd if the config was actually changed since it
        #      can kill VMs
        #
        if [[ ! -z "${restart_libvirtd}" ]]
        then
            service libvirtd restart >/dev/null 2>&1
        fi
    fi
    #
    # Added to enable iscsid and multipathd containers to start on OVM
    #
    echo '#!/bin/bash' > /etc/sysconfig/modules/configfs.modules
    echo 'exec /sbin/modprobe configfs > /dev/null 2>&1' >> /etc/sysconfig/modules/configfs.modules
    chmod 750 /etc/sysconfig/modules/configfs.modules
    /sbin/modprobe configfs
    #
    # Enable propagation of neutron dvr related namespace mounts for docker
    #
    cat > %{_sysconfdir}/rc.d/init.d/makeshared << "__EOF__"
#!/bin/sh
#       /etc/rc.d/init.d/makeshared
#       make-shared filesystem for neutron dvr
# chkconfig:   2345 94 94
# description: make-shared filesystem for neutron dvr

# Source function library.
. /etc/rc.d/init.d/functions

start() {
    mount --make-shared /
}

case "$1" in
    start)
        $1
        ;;
    stop)
        :
        ;;
    *)
        echo $"Usage: $0 {start|stop}"
        exit 2
        ;;
esac

exit $?
__EOF__

    chmod 750 %{_sysconfdir}/rc.d/init.d/makeshared
    chkconfig --add makeshared
    chkconfig makeshared on
    service makeshared start
    [[ -n "$(service docker status 2>/dev/null|grep running)" ]] && \
        service docker stop >/dev/null 2>&1
    [[ -z "$(chkconfig --list docker 2>/dev/null|grep on)" ]] && \
        chkconfig docker on >/dev/null 2>&1
    [[ -z "$(service docker status 2>/dev/null|grep running)" ]] && \
        service docker start >/dev/null 2>&1
elif test -x %{_bindir}/systemctl
then
    #
    # Set docker MountFlags=shared for neutron
    #
    mkdir -p %{_sysconfdir}/systemd/system/docker.service.d
    if ! test -f %{_sysconfdir}/systemd/system/docker.service.d/kolla.conf
    then
        cat > %{_sysconfdir}/systemd/system/docker.service.d/kolla.conf << __EOF__
[Service]
MountFlags=shared
__EOF__
        systemctl daemon-reload
        systemctl stop docker >/dev/null 2>&1
    fi
    [[ -n "$(systemctl show docker --property ActiveState|grep '=active')" ]] && \
        systemctl stop docker >/dev/null 2>&1
    [[ -z "$(systemctl show docker --property UnitFileState|grep '=enabled')" ]] && \
        systemctl enable docker >/dev/null 2>&1
    [[ -z "$(systemctl show docker --property ActiveState|grep '=active')" ]] && \
        systemctl start  docker >/dev/null 2>&1
fi
exit 0



%changelog
* Wed Jan 3 2018 James McCarthy <james.m.mccarthy@oracle.com> - 4.0.1-2.el6
- BUILDINFO: commit=ef606a27deb6a275c7fe632a5afa0a0c8ca43365
- Add rsync env for account & container replicators (Paul Bourke)  

* Wed Dec 13 2017 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 4.0.1-1
- BUILDINFO: commit=fdc021dbfd96af1dcef3a1ee4bbedeabe2f9e344
- Merge "Change properties to support new container tagging approach" into o3l_4.next

* Wed Dec 06 2017 - Borne Mace <borne.mace@oracle.com>
- Change openstack_registry property update behavior
- Change package_version to 4.0.1
- Added container_tag value and set to 4.0

* Tue Dec 05 2017 - Paul Bourke <paul.bourke@oracle.com>
- Enable Barbican by default

* Thu Nov 30 2017 - James McCarthy <james.m.mccarthy@oracle.com>
- Pin to specific docker-engine version

* Mon Nov 20 2017 - Paul Bourke <paul.bourke@oracle.com>
- Remove upper constraint on docker-engine (bug 27131294)

* Fri Nov 10 2017 - Mark Duggan <mark.duggan@oracle.com>
- Making consistent backup whih upgrading Kolla RPMs (bug 23137754)

* Wed Sep 20 2017 - Mick Thompson <mick.a.thompson@oracle.com>
- Update required ansible version (bug 26830443)

* Tue Sep 05 2017 Borne Mace <borne.mace@oracle.com>
- Added python2-cryptography requirement to openstack-kolla-ansible

* Thu Aug 31 2017 Paul Bourke <paul.bourke@oracle.com>
- Update permissions for docker-ostk to 755 (bug 26539004)

* Mon Jul 24 2017 - Mick Thompson <mick.a.thompson@oracle.com>
- Remove outdated check, which causes passwords file not to be merged

* Wed Jul 19 2017 - James McCarthy <james.m.mccarthy@oracle.com>
- Remedy glance mount point configuration to be backwards compatible (bug 26476213)

* Wed Jun 28 2017 - Mark Duggan <mark.duggan@oracle.com>
- Ensuring getting correct docker-engine version (1.12)

* Mon Jun 26 2017 - James McCarthy <james.m.mccarthy@oracle.com>
- Add some additional rpms to requires for kolla-ansible rpm (bug 25821760)

* Thu Jun 15 2017 - James McCarthy <james.m.mccarthy@oracle.com>
- Reduce file and directory permissions set at rpm installation (bug 25702662)

* Wed Mar 29 2017 Murali Annamneni <murali.annamneni@oracle.com>
- Add new License Text to kolla rpms

* Tue Mar 28 2017 - Murali Annamneni <murali.annamneni@oracle.com>
- Removed code relating to upgrade from 2.x to 4.x as this upgrade not supported

* Thu Mar 23 2017 - Murali Annamneni <murali.annamneni@oracle.com>
- Apply patches to retain 3.x installation directory structure

* Tue Mar 21 2017 - James McCarthy <james.m.mccarthy@oracle.com>
- Update rabbitmq_version property

* Wed Mar 15 2017 - Mick Thompson <michael.a.thompson@oracle.com>
- Change package_version to 4.0.0

* Tue Jan 10 2017 - James McCarthy <james.m.mccarthy@oracle.com>
- Change docker_registry setting to container-registry.oracle.com (bug 25367382)

* Mon Dec 19 2016 - Mick Thompson <michael.a.thompson@oracle.com>
- Removed global augment for nova upgrade (bug 25265636)

* Thu Dec 15 2016 - Mick Thompson <michael.a.thompson@oracle.com>
- Removed dnsmasq_dhcp_mtu token

* Wed Dec 14 2016 - Kevin Loughnane <kevin.loughnane@oracle.com>
- move line 362 up one line (typo) (bug 25253589)

* Wed Dec 14 2016 - Mick Thompson <michael.a.thompson@oracle.com>
- Added new dnsmasq_dhcp_mtu token and set to 1450 (bug 25244034)

* Wed Dec 14 2016 - Mick Thompson <michael.a.thompson@oracle.com>
- Split nova upgrade workaround between pre and post sections (bug 25177331)

* Mon Dec 12 2016 - Mick Thompson <michael.a.thompson@oracle.com>
- On upgrade one should set enable_aodh if ceilometer is enabled in 2.1.1 (bug 25222881)

* Mon Dec 12 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Mark the nova.conf augment specifically similar to other config files (bug 25057736)

* Thu Dec 08 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Check for 2.1.1 move this check to %pre, revert %post (bug 25057736)

* Tue Dec 06 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Check for 2.1.1 before checking for default release tag (bug 25057736)

* Tue Dec 06 2016 - Vladislav Belogrudov <vladislav.belogrudov@oracle.com>
- Check if new password file has been saved as .rpmnew on upgrade from 2.1.1 (bug 25189631)

* Fri Dec 02 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Additional check to be sure it's an upgrades from 2.1.1 (bug 25057736)

* Fri Dec 02 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- For upgrades from 2.1.1 create nova.conf augment to adjust username (bug 25057736)

* Tue Nov 29 2016 - Paul Bourke <paul.bourke@oracle.com>
- Fix defaults for cinder override values.

* Tue Nov 29 2016 - Murali Annamneni <murali.annamneni@oracle.com>
- invoke passwords.yml merge after install/update of kolla-ansible rpm. (bug 25163345)

* Wed Nov 23 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- add alias for ceilometer_database_type property for upgrades. (bug 25143307)

* Tue Nov 15 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Mark password.yml as a config file

* Mon Nov 14 2016 - Vladislav Belogrudov <vladislav.belogrudov@oracle.com>
- Fix location of systemctl

* Thu Nov 10 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fix syntax errors in post

* Thu Nov 10 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Wrap systemctl command to avoid execution on ovm (bug 25027507)

* Thu Nov 10 2016 - Kevin Loughnane <kevin.loughnane@oracle.com>
- Increase minimum docker-engine version to 1.12.0

* Mon Nov 07 2016 - Vladislav Belogrudov <vladislav.belogrudov@oracle.com>
- Added backward compatibility for ceilometer_database_address

* Tue Nov 01 2016 - Borne Mace <borne.mace@oracle.com>
- Added inclusion of stop-containers script in rpm

* Thu Oct 27 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Adjust changes for dvr to enable service as intended (bug 24845346)

* Mon Oct 24 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Added makeshared service to support shared dvr related mounts in OVM Server (bug 24845346)

* Fri Oct 14 2016 - Mark Duggan <mark.duggan@oracle.com>
- Enable murano by default in all.yml

* Fri Oct 14 2016 - Mark Duggan <mark.duggan@oracle.com>
- Added to enable iscsid and multipathd containers to start on OVM

* Thu Oct 13 2016 - Mark Duggan <mark.duggan@oracle.com>
- Setting default value for cinder_iscssi_helper to lioadm

* Thu Oct 13 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Added Oracle default values override for all.yml

* Thu Oct 13 2016 - Mick Thompson <michael.a.thompson@oracle.com>
- Exclude template-overrides.j2 from openstack-kolla-ansible

* Wed Oct 12 2016 - Paul Bourke <paul.bourke@oracle.com>
- Set ceilometer_database_type override to mysql

* Wed Oct 12 2016 - Paul Bourke <paul.bourke@oracle.com>
- Set nova_hw_disk_discard override to empty to disable

* Tue Oct 11 2016 - Borne Mace <borne.mace@oracle.com>
- add ansible destroy related scripts into installed kolla tools area.

* Thu Oct 06 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Added Oracle default values override for all.yml

* Thu Oct 06 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- add Requires for python-netaddr, needed for prechecks.

* Wed Sep 28 2016 - Mark Duggan <mark.duggan@oracle.com>
- Updating jinja2 version to 2.8 to fix deploy

* Wed Sep 21 2016 - Steve Noyes <steve.noyes@oracle.com>
- add MountFlags=shared to preinstall rpm

* Tue Sep 20 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- add alias for keepalived_virtual_router_id property for upgrades.

* Thu Sep 15 2016 - Steve Noyes <steve.noyes@oracle.com>
- add shadow-utils as reqt for kolla-user. Have useradd create kolla home directory.

* Wed Sep 14 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixed issues with kolla-genpwd (pbr not being able to find the version)
- Force RPM to only allow the exact kolla RPMs as dep resolution on install
- Added the new openstack env vars that should be kept when sudo for kolla

* Tue Sep 13 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added oracle default values override for all.yml

* Mon Sep 12 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Updated to align with updated upstream kolla
- fixing problem with /etc/kolla/config not existing by default

* Fri Jun 03 2016 - Steve Noyes <steve.noyes@oracle.com>
- make openstack-kolla-user dependent on openstack-kolla so it is removed with openstack-kolla

* Wed May 25 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Split out user creation from preinstall

* Mon May 23 2016 - Steve Noyes <steve.noyes@oracle.com>
- added new private ansible cfg file

* Fri Apr 29 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Updated the Ansible requirement to 2.1.0

* Wed Mar 16 2016 - Mark Duggan <mark.duggan@oracle.com>
- Added libvirtd.conf and sysconfig/libvirtd changes to test live migration

* Mon Mar 07 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added oswatcher to the services to be disabled on OVM

* Mon Mar 07 2016 - Borne Mace <borne.mace@oracle.com>
- added some post operations to support group / host variables

* Mon Feb 22 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fix update issues
- Fix issue where libvirtd is always restarted
- Update the openstack_release if need be when updating

* Fri Feb 19 2016 - Mark Duggan <mark.duggan@oracle.com>
- Minor changes in libvirtd.conf in OVM Server (bug 22762921)

* Thu Feb 18 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added back the OL7 required pieces
- Changed OVM check since ovs-info will always not exist if in kickstart
- Make the post be repeatable to allow RPM updates

* Wed Feb 17 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Changes required for OVM Server (bug 22731949)

* Fri Nov 06 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixed /etc/kolla/config file permissions (bug 21983235)
- Fixed user creation issues (bug 22098605)

* Fri Oct 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Renamed the kolla-tools package to kolla-utils
- Added a check to make sure sudoers.d gets inlcuded by sudoers

* Wed Sep 23 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added the kolla-tools package

* Tue Sep 15 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added OL6 support

* Thu Sep 10 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Changed the useradd to not create the home dir and only create it if need be
- Renamed the inventory directory inventory_samples

* Tue Sep 08 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Changed %config to %config(noreplace)

* Fri Sep 04 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixing file permissions and leaving kolla user alone on uninstall
- Fixed issue where post would sometime error exiting
- Changed the SSH dir create to be post rather then forcefully laying it down
- Change the Ansible config file to disable host key checking

* Wed Sep 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Initial release

